@@ -19,20 +19,20 @@
 
 /**
  * SECTION:element-rademux
- * @title: rademux
  *
  * Demuxes/parses a RealAudio (.ra) file or stream into compressed audio.
- *
- * ## Example launch line
+ * 
+ * <refsect2>
+ * <title>Example launch line</title>
  * |[
- * gst-launch-1.0 filesrc location=interview.ra ! rademux ! avdec_real_288 ! audioconvert ! audioresample ! autoaudiosink
+ * gst-launch filesrc location=interview.ra ! rademux ! ffdec_real_288 ! audioconvert ! audioresample ! alsasink
  * ]| Read a RealAudio file and decode it and output it to the soundcard using
  * the ALSA element. The .ra file is assumed to contain RealAudio version 2.
  * |[
- * gst-launch-1.0 souphttpsrc location=http://www.example.org/interview.ra ! rademux ! ac3parse ! a52dec ! audioconvert ! audioresample ! autoaudiosink
+ * gst-launch gnomevfssrc location=http://www.example.org/interview.ra ! rademux ! a52dec ! audioconvert ! audioresample ! alsasink
  * ]| Stream RealAudio data containing AC3 (dnet) compressed audio and decode it
- * and output it to the soundcard.
- *
+ * and output it to the soundcard using the ALSA element.
+ * </refsect2>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -61,8 +61,6 @@ GST_DEBUG_CATEGORY_STATIC (real_audio_demux_debug);
 
 #define gst_real_audio_demux_parent_class parent_class
 G_DEFINE_TYPE (GstRealAudioDemux, gst_real_audio_demux, GST_TYPE_ELEMENT);
-GST_ELEMENT_REGISTER_DEFINE (rademux, "rademux",
-    GST_RANK_SECONDARY, GST_TYPE_REAL_AUDIO_DEMUX);
 
 static GstStateChangeReturn gst_real_audio_demux_change_state (GstElement * e,
     GstStateChange transition);
@@ -98,8 +96,10 @@ gst_real_audio_demux_class_init (GstRealAudioDemuxClass * klass)
 
   gobject_class->finalize = gst_real_audio_demux_finalize;
 
-  gst_element_class_add_static_pad_template (gstelement_class, &sink_template);
-  gst_element_class_add_static_pad_template (gstelement_class, &src_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&src_template));
 
   gst_element_class_set_static_metadata (gstelement_class, "RealAudio Demuxer",
       "Codec/Demuxer",
@@ -595,14 +595,14 @@ gst_real_audio_demux_handle_buffer (GstRealAudioDemux * demux, GstBuffer * buf)
       ret = gst_real_audio_demux_parse_marker (demux);
       if (ret != GST_FLOW_OK || demux->state != REAL_AUDIO_DEMUX_STATE_HEADER)
         break;
+      /* otherwise fall through */
     }
-      /* FALLTHROUGH */
     case REAL_AUDIO_DEMUX_STATE_HEADER:{
       ret = gst_real_audio_demux_parse_header (demux);
       if (ret != GST_FLOW_OK || demux->state != REAL_AUDIO_DEMUX_STATE_DATA)
         break;
+      /* otherwise fall through */
     }
-      /* FALLTHROUGH */
     case REAL_AUDIO_DEMUX_STATE_DATA:{
       ret = gst_real_audio_demux_parse_data (demux);
       break;
@@ -998,3 +998,10 @@ gst_real_audio_demux_change_state (GstElement * element,
 
   return ret;
 }
+
+gboolean
+gst_rademux_plugin_init (GstPlugin * plugin)
+{
+  return gst_element_register (plugin, "rademux",
+      GST_RANK_SECONDARY, GST_TYPE_REAL_AUDIO_DEMUX);
+}
